# Copyright (c) 2026 Isometric HQ Ltd
# Licensed under PolyForm Noncommercial 1.0.0
# https://polyformproject.org/licenses/noncommercial/1.0.0/

"""
Re-exported dependencies of `isometric_calculation_library`.

This library acts as a choke point for external dependencies. As long as a Python module imports
only from `isometric_calculation_library`, this library's version alone is sufficient to reproduce
all its dependencies.
"""

import geopandas
import numpy  # noqa: ICN001
import pandas  # noqa: ICN001
import shapely

__all__ = [
    "geopandas",
    "numpy",
    "pandas",
    "shapely",
]



# Copyright (c) 2026 Isometric HQ Ltd
# Licensed under PolyForm Noncommercial 1.0.0
# https://polyformproject.org/licenses/noncommercial/1.0.0/

from collections.abc import Callable
from typing import NewType

__version__ = "0.16.0"
"""Version format: M.R.0 where M is the major version, R is a revision number incrementing on each release, and the patch number is always 0."""

ModelKey = NewType("ModelKey", str)

type ModelImplementation = Callable[..., object]
